import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-elasticbeanstalk",
    "1.71.0",
    __name__[0:-6],
    "aws-elasticbeanstalk@1.71.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
